@@ -5,11 +5,12 @@
 # 
 # test_package("umx")
 test_that("umx_rename works for different values", {
+	data(mtcars)
 	x = mtcars
 	oldNames <- c("mpg", "cyl", "disp", "hp", "drat", "wt", "qsec", "vs", "am", "gear", "carb")
 	newNames = oldNames
 	newNames[2] = "cylinder"
-	x = umx_rename(x, replace = c(cyl = "cylinder"))
+	x = umx_rename(x, to = c(cyl = "cylinder"))
 	expect_equal(names(x), newNames)
 
 	# ==============================
@@ -20,14 +21,13 @@ test_that("umx_rename works for different values", {
 	#   The following names did not appear in the dataframe:cyl
 	# perhaps you already updated them"
 
-	expect_warning(umx_rename(x, replace = c(cyl = "cylinder")))
+	expect_warning(umx_rename(x, to = c(cyl = "cylinder")))
 
-	expect_warning(umx_rename(x, replace = c(cyl = "cylinder")))
+	expect_warning(umx_rename(x, to = c(cyl = "cylinder")))
 
 	# alternate style
 	x = mtcars
-	umx_rename(x, old = c("cyl"), replace = c("cylinder"), test=T)
-	
-	x = umx_rename(x, old = c("cyl"), replace = c("cylinder"))
+	umx_rename(x, from = c("cyl"), to = c("cylinder"), test=TRUE)	
+	x = umx_rename(x, from = "cyl", to = "cylinder")
 	expect_equal(names(x), newNames)
 })
